@@ -1,8 +1,8 @@
 package Alien::Kiwisolver;
 # ABSTRACT: Alien package for the Kiwi C++ implementation of the Cassowary constraint solving algorithm
-$Alien::Kiwisolver::VERSION = '0.002_002'; # TRIAL
+$Alien::Kiwisolver::VERSION = '0.002_003'; # TRIAL
 
-$Alien::Kiwisolver::VERSION = '0.002002';
+$Alien::Kiwisolver::VERSION = '0.002003';
 use strict;
 use warnings;
 
@@ -18,7 +18,7 @@ sub Inline {
 	if( $lang =~ /^CPP$/ ) {
 		my $params = Alien::Base::Inline(@_);
 
-		$params->{CCFLAGSEX} = '-std=c++11';
+		$params->{CCFLAGSEX} = $self->runtime_prop->{cppstdflag};
 
 		$params->{PRE_HEAD} = <<'		EOF';
 		#if defined(_MSC_VER) || defined(__MINGW32__)
@@ -51,7 +51,7 @@ Alien::Kiwisolver - Alien package for the Kiwi C++ implementation of the Cassowa
 
 =head1 VERSION
 
-version 0.002_002
+version 0.002_003
 
 =head1 Inline support
 
